AnimateCommand enum

A command emitted by an AnimateController to a driven animation.

Inheritance
Available extensions

Values

play → const AnimateCommand

Play forward from the current position to the end.

reverse → const AnimateCommand

Play backward from the current position to the start.

reset → const AnimateCommand

Jump back to the start without animating.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AnimateCommand>
A constant List of the values in this enum, in order of their declaration.