GradientFlow class
Paints child's pixels with a flowing, animated two-color gradient.
Perfect for "living" gradient text or icons. Uses BlendMode.srcATop so
only the visible parts of the child are tinted. GPU-powered via
gradient_flow.frag.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- GradientFlow
- Available extensions
Constructors
Properties
- child → Widget
-
final
- colorA → Color
-
final
- colorB → Color
-
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speed → double
-
final
Methods
-
blurIn(
{double sigma = AnimateDefaults.blurSigma, bool fade = true, Duration duration = AnimateDefaults.duration, Curve curve = AnimateDefaults.curve, Duration delay = AnimateDefaults.delay, AnimateTrigger trigger = AnimateTrigger.onAppear, AnimateController? controller}) → Widget -
Available on Widget, provided by the AnimateX extension
Reveal by un-blurring. See BlurIn. -
bouncyTap(
{VoidCallback? onTap, double overshoot = 1.18, Duration duration = const Duration(milliseconds: 520), bool haptics = false}) → Widget -
Available on Widget, provided by the AnimateX extension
Springy bounce on tap. See BouncyTap. -
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
dissolve(
{bool reveal = true, Color edgeColor = const Color(0xFFFF7A18), Duration duration = const Duration(milliseconds: 900), Curve curve = Curves.easeInOut, Duration delay = AnimateDefaults.delay, AnimateTrigger trigger = AnimateTrigger.onAppear, AnimateController? controller}) → Widget -
Available on Widget, provided by the AnimateX extension
Noisy dissolve in/out with a burn edge. See Dissolve. -
fadeIn(
{Duration duration = AnimateDefaults.duration, Curve curve = AnimateDefaults.curve, Duration delay = AnimateDefaults.delay, AnimateTrigger trigger = AnimateTrigger.onAppear, AnimateController? controller}) → Widget -
Available on Widget, provided by the AnimateX extension
Fade in. See FadeIn. -
flipIn(
{FlipAxis axis = FlipAxis.horizontal, double beginTurns = 0.25, bool fade = true, Duration duration = AnimateDefaults.duration, Curve curve = AnimateDefaults.curve, Duration delay = AnimateDefaults.delay, AnimateTrigger trigger = AnimateTrigger.onAppear, AnimateController? controller}) → Widget -
Available on Widget, provided by the AnimateX extension
Flip into view in 3D. See FlipIn. -
glow(
{Color color = const Color(0xFF7C4DFF), double intensity = 0.9, double speed = 1.0, bool enabled = true}) → Widget -
Available on Widget, provided by the AnimateX extension
Pulsing GPU glow behind the widget. See Glow. -
gradientFlow(
{Color colorA = const Color(0xFFFF6CAB), Color colorB = const Color(0xFF7366FF), double speed = 1.0, bool enabled = true}) → Widget -
Available on Widget, provided by the AnimateX extension
Flowing animated gradient over the widget's pixels. See GradientFlow. -
jiggle(
{bool enabled = true, double angle = 0.06, Duration period = const Duration(milliseconds: 320)}) → Widget -
Available on Widget, provided by the AnimateX extension
Continuous attention wiggle. See Jiggle. -
liquid(
{Color colorA = const Color(0xFF5B247A), Color colorB = const Color(0xFF1BCEDF), double speed = 1.0, bool enabled = true}) → Widget -
Available on Widget, provided by the AnimateX extension
Swirling liquid plasma background. See Liquid. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pressScale(
{VoidCallback? onTap, double pressedScale = 0.94, Duration duration = AnimateDefaults.tapDuration, Curve curve = Curves.easeOut, bool haptics = false}) → Widget -
Available on Widget, provided by the AnimateX extension
Shrink-on-press feedback. See PressScale. -
printIn(
{RevealEdge from = RevealEdge.top, bool fade = false, bool showSlot = false, Color slotColor = const Color(0x33000000), double slotThickness = 12.0, Duration duration = const Duration(milliseconds: 700), Curve curve = Curves.easeOutCubic, Duration delay = AnimateDefaults.delay, AnimateTrigger trigger = AnimateTrigger.onAppear, AnimateController? controller}) → Widget -
Available on Widget, provided by the AnimateX extension
Unroll into view through a slot, like a printing receipt. See PrintIn. -
rippleTap(
{VoidCallback? onTap, Color color = const Color(0x33FFFFFF), Duration duration = const Duration(milliseconds: 600), bool haptics = false}) → Widget -
Available on Widget, provided by the AnimateX extension
Expanding ripple from the touch point. See RippleTap. -
scaleIn(
{double begin = AnimateDefaults.scaleBegin, bool fade = true, Alignment alignment = Alignment.center, Duration duration = AnimateDefaults.duration, Curve curve = Curves.easeOutBack, Duration delay = AnimateDefaults.delay, AnimateTrigger trigger = AnimateTrigger.onAppear, AnimateController? controller}) → Widget -
Available on Widget, provided by the AnimateX extension
Scale up while fading in. See ScaleIn. -
shimmer(
{Color baseColor = const Color(0xFFE0E0E0), Color highlightColor = const Color(0xFFF5F5F5), Duration duration = AnimateDefaults.loopDuration, bool enabled = true}) → Widget -
Available on Widget, provided by the AnimateX extension
Looping shimmer sweep. See Shimmer. -
slideDown(
{double offset = AnimateDefaults.slideOffset, bool fade = true, Duration duration = AnimateDefaults.duration, Curve curve = AnimateDefaults.curve, Duration delay = AnimateDefaults.delay, AnimateTrigger trigger = AnimateTrigger.onAppear, AnimateController? controller}) → Widget -
Available on Widget, provided by the AnimateX extension
Slide down while fading in. See SlideIn. -
slideInLeft(
{double offset = AnimateDefaults.slideOffset, bool fade = true, Duration duration = AnimateDefaults.duration, Curve curve = AnimateDefaults.curve, Duration delay = AnimateDefaults.delay, AnimateTrigger trigger = AnimateTrigger.onAppear, AnimateController? controller}) → Widget -
Available on Widget, provided by the AnimateX extension
Slide in from the right. See SlideIn. -
slideInRight(
{double offset = AnimateDefaults.slideOffset, bool fade = true, Duration duration = AnimateDefaults.duration, Curve curve = AnimateDefaults.curve, Duration delay = AnimateDefaults.delay, AnimateTrigger trigger = AnimateTrigger.onAppear, AnimateController? controller}) → Widget -
Available on Widget, provided by the AnimateX extension
Slide in from the left. See SlideIn. -
slideUp(
{double offset = AnimateDefaults.slideOffset, bool fade = true, Duration duration = AnimateDefaults.duration, Curve curve = AnimateDefaults.curve, Duration delay = AnimateDefaults.delay, AnimateTrigger trigger = AnimateTrigger.onAppear, AnimateController? controller}) → Widget -
Available on Widget, provided by the AnimateX extension
Slide up while fading in. See SlideIn. -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited